@@ -53,6 +53,7 @@ from .Dialogs import (DistUpgradeDialog,
                       HWEUpgradeDialog,
                       NeedRestartDialog,
                       NoUpdatesDialog,
+                      NoUpgradeForYouDialog,
                       PartialUpgradeDialog,
                       StoppedUpdatesDialog,
                       UnsupportedDialog,
@@ -63,7 +64,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_dist
+from .Core.utils import get_arch, get_dist
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -87,6 +88,7 @@ class UpdateManager(Gtk.Window):
         self.update_list = None
         self.meta_release = None
         self.hwe_replacement_packages = None
+        self.arch = get_arch()
 
         # Basic GTK+ parameters
         self.set_title(_("Software Updater"))
@@ -237,6 +239,9 @@ class UpdateManager(Gtk.Window):
         self._look_busy()
         self.refresh_cache()
 
+        if self.cache is None:
+            return
+
         pane = self._make_available_pane(self.cache.install_count,
                                          os.path.exists(REBOOT_REQUIRED_FILE),
                                          cancelled_update, error_occurred)
@@ -312,6 +317,9 @@ class UpdateManager(Gtk.Window):
         if (self.meta_release.new_dist and
                 (self.options.check_dist_upgrades or
                  settings.get_boolean("check-dist-upgrades"))):
+            if self.arch == 'i386':
+                return NoUpgradeForYouDialog(self, self.meta_release,
+                                             self.arch)
             return DistUpgradeDialog(self, self.meta_release)
 
         return None
@@ -380,7 +388,8 @@ class UpdateManager(Gtk.Window):
                      "Please use the package manager \"Synaptic\" or run "
                      "\"sudo apt-get install -f\" in a terminal to fix "
                      "this issue at first.")
-            self.start_error(True, header, desc)
+            self.start_error(False, header, desc)
+            return
         except SystemError as e:
             header = _("Could not initialize the package information")
             desc = _("An unresolvable problem occurred while "
@@ -388,7 +397,8 @@ class UpdateManager(Gtk.Window):
                      "Please report this bug against the 'update-manager' "
                      "package and include the following error "
                      "message:\n") + str(e)
-            self.start_error(True, header, desc)
+            self.start_error(False, header, desc)
+            return
 
         # Let the Gtk event loop breath if it hasn't had a chance.
         def iterate():
